<?php
/*+***********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *************************************************************************************/
$languageStrings = array(
    'Email Templates' => 'Email Templates',
	'LBL_ADD_RECORD' => 'Add Email Template',
	'SINGLE_EmailTemplates' => 'Email Template',
	'LBL_EMAIL_TEMPLATES'=> 'Email Templates',
	'LBL_EMAIL_TEMPLATE' => 'Email Template',
	
	'LBL_TEMPLATE_NAME' => 'Template name',
	'LBL_DESCRIPTION' => 'Description',
	'LBL_SUBJECT' => 'Subject',
	'LBL_GENERAL_FIELDS' => 'General Fields',
	'LBL_SELECT_FIELD_TYPE' => 'Selecteer Module & Field',
	'LBL_MODULE_NAME' => 'Module Name',
	'LBL_EMAIL_TEMPLATE_DESCRIPTION'=>'Manage templates for E-Mail module',
	'LBL_NO_PERMISSIONS_TO_DELETE_SYSTEM_TEMPLATE' => 'Geen Machtigingen naar Verwijderen System Template',
	'LBL_RECORD_ID'                => 'Record-ID'                   , 
	
);

$jsLanguageStrings = array(
    'LBL_CUTOMER_LOGIN_DETAILS_TEMPLATE_DELETE_MESSAGE' => 'U zult niet in staat zijn om de customer portal login gegevens te sturen naar de contactpersoon als u "Klanten Login Gegevens" sjabloon verwijderen. Wilt u doorgaan?',
	'JS_REQUIRED_FIELD' => '* Bericht is vereist',
);